@@ -1,7 +1,7 @@
 import datetime
 import uuid
 
-from django.db import models
+from djongo import models
 
 
 class AuditoryModel(models.Model):
