@@ -9,21 +9,24 @@ class Profiles:
     file_config = yaml.load(open('profile.yaml'), Loader=yaml.FullLoader)['django']
     APP_NAME = file_config['application']['name']
     PROFILE = file_config['profiles']['active']
-    ENVIRONMENTS = f'{APP_NAME}-{PROFILE}.yml'
-    URI = file_config['cloud']['config']['uri'] + ENVIRONMENTS
+    ENVIRONMENTS = f'.environments/{APP_NAME}-{PROFILE}.yml'
     APPLICATION = file_config['application']
     CONFIG = {}
     env = {}
 
-    def get_env(self):
+    def get_general_env(self):
+        return self.APPLICATION
+
+    def get_specific_env(self):
         try:
-            # r = requests.get(self.URI, allow_redirects=True)
-            # open(self.ENVIRONMENTS, 'wb').write(r.content)
             self.env = yaml.load(open(self.ENVIRONMENTS), Loader=yaml.FullLoader)['django']
-            self.CONFIG = self.env['cloud']['config']
+            self.CONFIG = self.env['application']['config']
             print(colored('ARCHIVO DE CONFIGURACIONES -> ' + self.ENVIRONMENTS, 'green'))
         except Exception as e:
             raise GenericMicroserviceError(status=500, detail=f'ERROR CONFIG ENV: {e}')
 
+    def get_email_env(self):
+        return self.env['application']['email']
+
     def get_operating_system(self):
         return self.file_config.get('operating-system')
