@@ -46,6 +46,9 @@ class Constants:
     EXPIRED = 'EXPIRADO'
     INVALID = 'INVALIDO'
     PHOTO_DEFAULT = '3fa85f64-5717-4562-b3fc-2c963f66afa6'
+    WINDOWS = 'win'
+    LINUX = 'linux'
+    MACOS = 'mac'
 
 
 class FrontendUrl:
